@@ -32,11 +32,9 @@
 #include "khtml_part.h"
 
 #include "misc/loader.h"
-#include "misc/helper.h"
 
 #include "css/cssstyleselector.h"
 #include "css/css_stylesheetimpl.h"
-#include "css/csshelper.h"
 #include "css/css_mediaquery.h"
 
 #include "ecma/kjs_proxy.h"
@@ -56,7 +54,7 @@ void HTMLBaseElementImpl::parseAttribute(AttributeImpl *attr)
 {
     switch (attr->id()) {
     case ATTR_HREF:
-        m_href = khtml::parseURL(attr->value());
+        m_href = attr->value().trimSpaces().string();
         process();
         break;
     case ATTR_TARGET:
@@ -91,7 +89,7 @@ void HTMLBaseElementImpl::process()
     }
 
     if (!m_href.isEmpty() && document()->part()) {
-        document()->setBaseURL(QUrl(document()->part()->url()).resolved(QUrl(m_href.string())));
+        document()->setBaseURL(QUrl(document()->part()->url()).resolved(QUrl(m_href)));
     }
 
     if (!m_target.isEmpty()) {
@@ -121,10 +119,14 @@ NodeImpl::Id HTMLLinkElementImpl::id() const
 void HTMLLinkElementImpl::parseAttribute(AttributeImpl *attr)
 {
     switch (attr->id()) {
-    case ATTR_HREF:
-        m_url = document()->completeURL(khtml::parseURL(attr->value()).string());
+    case ATTR_HREF: {
+        const DOMString hrefUrl = attr->value().trimSpaces();
+        if (!hrefUrl.isEmpty()) {
+            m_url = document()->completeURL(hrefUrl.string());
+        }
         process();
         break;
+    }
     case ATTR_REL:
     case ATTR_TYPE:
         process();
@@ -180,25 +182,41 @@ void HTMLLinkElementImpl::parseAttribute(AttributeImpl *attr)
     }
 }
 
+static inline bool isIconLink(const QString &relAttribute)
+{
+    // http://www.w3.org/TR/html5/links.html#linkTypes:
+    // split rel attribute on spaces and search for "icon" keyword.
+    // note: relAttribute is supposed to be a lower case string
+    const QLatin1String icon("icon");
+    int iconPos = relAttribute.indexOf(icon);
+    while (iconPos != -1) {
+        const bool found = (iconPos == 0 || relAttribute.at(iconPos - 1).isSpace()) &&
+                           (((iconPos + 4) == relAttribute.length()) || relAttribute.at(iconPos + 4).isSpace());
+        if (found) {
+            return true;
+        }
+        iconPos = relAttribute.indexOf(icon, iconPos + 5);
+    }
+
+    return false;
+}
+
 void HTMLLinkElementImpl::process()
 {
     if (!inDocument()) {
         return;
     }
 
-    QString type = getAttribute(ATTR_TYPE).string().toLower();
-    QString rel = getAttribute(ATTR_REL).string().toLower();
+    //QString type = getAttribute(ATTR_TYPE).string().toLower();
+    const QString rel = getAttribute(ATTR_REL).string().toLower();
 
     KHTMLPart *part = document()->part();
 
-    // IE extension: location of small icon for locationbar / bookmarks
-    // Uses both "shortcut icon" and "icon"
-    if (part && rel.contains("icon") && !m_url.isEmpty() && !part->parentPart()) {
+    // Location of small icon for locationbar / bookmarks (aka "favicon")
+    if (isIconLink(rel) && !m_url.isEmpty() && part && !part->parentPart()) {
         part->browserExtension()->setIconUrl(QUrl(m_url.string()));
-    }
-
-    // Stylesheet
-    else if (!m_isDisabled && rel.contains("stylesheet")) {
+    } // Stylesheet
+    else if (rel.contains("stylesheet") && !m_url.isEmpty() && !m_isDisabled) {
         // no need to load style sheets which aren't for the screen output
         // ### there may be in some situations e.g. for an editor or script to manipulate
         khtml::MediaQueryEvaluator allEval(true);
@@ -406,7 +424,7 @@ void HTMLScriptElementImpl::parseAttribute(AttributeImpl *attr)
         if (m_evaluated || m_cachedScript || m_createdByParser || !inDocument()) {
             return;
         }
-        DOMString url = attr->value();
+        const DOMString url = attr->value().trimSpaces();
         if (!url.isEmpty()) {
             loadFromUrl(url);
         }
@@ -516,7 +534,7 @@ void HTMLScriptElementImpl::insertedIntoDocument()
         return;
     }
 
-    DOMString url = getAttribute(ATTR_SRC).string();
+    const DOMString url = getAttribute(ATTR_SRC).trimSpaces();
     if (!url.isEmpty()) {
         loadFromUrl(url);
         return;
@@ -651,7 +669,7 @@ void HTMLScriptElementImpl::setDefer(bool defer)
 
 DOMString HTMLScriptElementImpl::src() const
 {
-    return document()->completeURL(getAttribute(ATTR_SRC).string());
+    return document()->completeURL(getAttribute(ATTR_SRC).trimSpaces().string());
 }
 
 void HTMLScriptElementImpl::setSrc(const DOMString &value)
